@@ -4,7 +4,7 @@
   mxQueue -- A queue implementation
 
   Copyright (c) 1998-2000, Marc-Andre Lemburg; mailto:mal@lemburg.com
-  Copyright (c) 2000-2011, eGenix.com Software GmbH; mailto:info@egenix.com
+  Copyright (c) 2000-2014, eGenix.com Software GmbH; mailto:info@egenix.com
   See the documentation for further copyright information or contact
   the author (mailto:mal@lemburg.com).
   
@@ -147,12 +147,12 @@ int mxQueue_ImportModuleAndAPI(void)
     v = PyObject_GetAttrString(mod,MXQUEUE_MODULE"API");
     if (v == NULL)
 	goto onError;
-    Py_DECREF(mod);
+    Py_CLEAR(mod);
     DPRINTF(" API object found\n");
     api = PyCObject_AsVoidPtr(v);
     if (api == NULL)
 	goto onError;
-    Py_DECREF(v);
+    Py_CLEAR(v);
     memcpy(&mxQueue,api,sizeof(mxQueue));
     DPRINTF(" API object initialized.\n");
     return 0;
